@@ -45,7 +45,7 @@ lines(x, Xp %*% cf)
 
 ### Legendre to Bernstein
 ## Example from doi: 10.1016/j.amc.2007.09.050
-A <- basefun:::L2B(4L)
+A <- basefun:::.L2B(4L)
 B <- cbind(1, c(-1, -.5, 0, .5, 1), 
               c(1, -.5, -1, -.5, 1), 
               c(-1, 2, 0, -2, 1),  
@@ -53,4 +53,4 @@ B <- cbind(1, c(-1, -.5, 0, .5, 1),
 stopifnot(max(abs(A - B)) < .Machine$double.eps)
 
 ### Bernstein to Legendre
-stopifnot(max(abs(solve(A) - basefun:::B2L(4L))) < sqrt(.Machine$double.eps))
+stopifnot(max(abs(solve(A) - basefun:::.B2L(4L))) < sqrt(.Machine$double.eps))
